version 14.1
set more off
capture log close

log using strategies.log, replace

*     ***************************************************************** *;
*     ***************************************************************** *;
*   File-Name:  strategy.do  	                                        *;
*   Date:       September 4, 2016	                                    *;
*   Author:     Dellmuth and Tallberg                                   *;
*   Purpose:    Replicate results for paper "Advocacy Strategies in     *;
*				Global Governance: Inside vs. Outside Lobbying"		    *;
*   Input File: strategy.dta                  	                        *;
*   Output File:strategies.log		                                    *;
*     ****************************************************************  *;
*     ****************************************************************  *;


*     ****************************************************************  *;
*     Table 1															*;
*     ****************************************************************  *;

factor str_newsm str_social str_campaign str_info str_formal str_reprviews  ///
str_interact, pcf

rotate, promax horst

predict factor1 factor2

rename factor1 inside
rename factor2 outside

*Appendix Figure C1
screeplot, scheme(sj) graphregion(color(white))
  
*Generate dependent variable
gen relstr=inside-outside

*Robustness check with additive indices
gen outsideindex=str_newsm +str_social+ str_campaign 
gen insideindex=str_info +str_formal+ str_reprviews + str_interact
corr inside insideindex 
corr outside outsideindex
alpha str_newsm str_social str_campaign
alpha str_info str_formal str_reprviews str_interact 


*     ****************************************************************  *;
*     Table 2															*;
*     ****************************************************************  *;

tab  goals_impact if membership==1
tab  goals_vis if membership==1
tab  goals_info if membership==1
tab  goals_funds if membership==1

tab  goals_impact if membership==0
tab  goals_vis if membership==0
tab  goals_info if membership==0
tab  goals_funds if membership==0

tab  goals_impact  
tab  goals_vis 
tab  goals_info 
tab  goals_funds


*     ****************************************************************  *;
*     Table 3															*;
*     ****************************************************************  *;

reg relstr goals_impact goals_impactxmembership staff access regul 
gen sample=0
replace sample=1 if e(sample)
tab sample

*Check for multicollinearity
collin goals_impact goals_impactxmembership staff access regul if sample==1 

set more off 
svyset id [pw=dweight]
svy: reg relstr goals_impact if sample==1
eststo m1
svy:reg relstr goals_impact membership staff access regul if sample==1
eststo m2
svy:reg relstr goals_impact membership goals_impactxmembership if sample==1
eststo m3
svy:reg relstr goals_impact membership goals_impactxmembership staff access regul if sample==1
eststo m4 

esttab m1 m2 m3 m4, starlevels(* .10 ** .05 *** .01) main(b %9.3f) se(%9.3f) ///
nodepvars replace r2(%9.3f)

*     ****************************************************************  *;
*     Figure 1											 		        *;
*     ****************************************************************  *;

tab wr_alphabetical, nol
tab staff

graph dot (mean) staff [pweight = dweight], over(wr_alphabetical) dots(mcolor(edkblue) ///
msymbol(circle_hollow)) ylabel(, labels) ymtick(1(1)7)


*     ****************************************************************  *;
*     Figure 2											 		        *;
*     ****************************************************************  *;

svy:reg relstr goals_impact membership goals_impactxmembership staff access regul if sample==1

matrix b=e(b) 
matrix V=e(V)
 
scalar b1=b[1,1] 
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar b4=b[1,4]
scalar b5=b[1,5]
scalar b6=b[1,6] 

scalar varb1=V[1,1] 
scalar varb2=V[2,2] 
scalar varb3=V[3,3]
scalar varb4=V[4,4]
scalar varb5=V[5,5]
scalar varb6=V[6,6] 

scalar covb1b3=V[1,3] 
scalar covb2b3=V[2,3] 

scalar list b1 b2 b3 b4 b5 b6  varb1 varb2 varb3 varb4 varb5 varb6 covb1b3 covb2b3

gen conb0=b1                                   /* Marginal Effect if Z==0 */
gen conb1=b1+b3*1                              /* Marginal Effect if Z==1 */

gen conse0=sqrt(varb1+varb3*(0^2)+2*covb1b3*0)   /* if Z==0 */
gen conse1=sqrt(varb1+varb3*(1^2)+2*covb1b3*1)   /* if Z==1 */

gen upper0=conb0+1.96*conse0
gen lower0=conb0-1.96*conse0

gen upper1=conb1+1.96*conse1
gen lower1=conb1-1.96*conse1

gen upper = upper0     if membership==0
replace upper = upper1 if membership==1

gen lower = lower0     if membership==0
replace lower = lower1 if membership==1

gen con = conb0        if membership==0
replace con = conb1    if membership==1

#delimit ;
eclplot con lower upper membership, 
estopts(msize(large)) ciopts(msize(large))
xlab(0 1) xtitle("Membership organization", size(4))
ytitle("Marginal effect of seeking influence", size(4))			
xscale(range(-1 2)) yline(0, lcolor(black) lpattern(dash))
scheme(lean2) ylabel(, nogrid) legend(position(6));
;
#delimit cr


*     ****************************************************************  *;
*     Appendix files and robustness checks	    						*;
*     ****************************************************************  *;

*Table C1

#delimit ;
tabstat str_newsm str_social str_campaign str_info str_formal str_reprviews  
str_interact inside outside relstr goals_impact staff access regul 
if sample==1, stats(min mean max sd) columns(statistics) 
;
#delimit ;

*Table C2

corr goals_impact membership staff access regul if sample==1 

*Table C3

*Look at missing values
misschk goals_impact membership staff access regul , gen(dummy)
tab dummynumber 
tab dummypattern 
*Test MAR
gen missing=0
replace missing=1 if goals_impact==.| staff==.
logit missing
logit dummynumber membership access regul
*Impute and do analyses
preserve
set more off 
gen id=_n
mi set wide
mi register imputed goals_impact staff
mi svyset id [pweight = dweight], strata(frame)
noisily mi impute chain (regress) goals_impact  (regress) staff, rseed(123456) add(5) force
mi estimate: reg relstr goals_impact 
mi estimate:reg relstr goals_impact membership staff access regul 
mi estimate:reg relstr goals_impact membership goals_impactxmembership 
mi estimate:reg relstr goals_impact membership goals_impactxmembership staff access regul 
mi unset

*Table C4

set more off  
svy: reg relstr goals_impact i.wr if sample==1
eststo m1
svy:reg relstr goals_impact membership staff access regul  i.wr if sample==1
eststo m2
svy:reg relstr goals_impact membership goals_impactxmembership  i.wr if sample==1
eststo m3
svy:reg relstr goals_impact membership goals_impactxmembership staff access regul  i.wr if sample==1
eststo m4 

esttab m1 m2 m3 m4, starlevels(* .10 ** .05 *** .01) main(b %9.3f) se(%9.3f) ///
nodepvars replace  r2(%9.3f) 

*Table C5 

set more off  
svy: reg relstr goals_impact frame if sample==1
eststo m1
svy:reg relstr goals_impact membership staff access regul frame if sample==1
eststo m2
svy:reg relstr goals_impact membership goals_impactxmembership frame if sample==1
eststo m3
svy:reg relstr goals_impact membership goals_impactxmembership staff access regul frame if sample==1
eststo m4 

esttab m1 m2 m3 m4, starlevels(* .10 ** .05 *** .01) main(b %9.3f) se(%9.3f) ///
nodepvars replace  r2(%9.3f)
 

*Figure C2

kdensity relstr, scheme(sj) graphregion(color(white))

*Figure C3

gen one=1
graph bar (sum) one , over(country) scheme(sj) ///
graphregion(color(white)) ytitle(Number of NGOs,) 

log close
exit
